@@ -10,7 +10,7 @@ WWW::Shorten::GitHub - Shorten GitHub URLs using GitHub's URL shortener - git.io
 
 This module provides a perl interface to GitHub's URL shortening service, git.io.
 
-It allows you to shorten any GitHub URL, and also retrieve the original URL from 
+It allows you to shorten any GitHub URL, and also retrieve the original URL from
 a pre-shortened URL
 
 =head1 USAGE
@@ -29,7 +29,7 @@ use warnings;
 use base qw(WWW::Shorten::generic Exporter);
 
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5';
 
 use Carp;
 use URI;
@@ -37,13 +37,13 @@ use URI;
 sub makeashorterlink {
     my $url = shift or croak 'No URL passed to makeashorterlink';
 
-    my $host = URI->new($url)->host();    
+    my $host = URI->new($url)->host();
     if ($host !~ m/^(gist\.)?github\.com$/) {
         croak "Git.io only shortens URLs under the github.com domain";
     }
 
     my $ua = __PACKAGE__->ua();
-    my $response = $ua->post('http://git.io/create', [
+    my $response = $ua->post('https://git.io/create', [
         url    => $url,
         source => 'PerlAPI-' . (defined __PACKAGE__->VERSION ? __PACKAGE__->VERSION : 'dev'),
         format => 'simple',
@@ -55,8 +55,8 @@ sub makeashorterlink {
 
     return;
 }
- 
- 
+
+
 sub makealongerlink {
     my $token = shift or croak 'No URL / Git.io token passed to makealongerlink';
 
